@@ -300,11 +300,8 @@ impl TryFrom<time::OffsetDateTime> for Timestamp {
     type Error = TimestampError;
 
     fn try_from(value: time::OffsetDateTime) -> Result<Self, Self::Error> {
-        use time::convert::{Nanosecond, Second};
-
         let seconds = value.unix_timestamp();
-        let nanos = (value.unix_timestamp_nanos()
-            - seconds as i128 * Nanosecond::per(Second) as i128) as i32;
+        let nanos = (value.unix_timestamp_nanos() - seconds as i128 * NS) as i32;
         Self::new(seconds, nanos)
     }
 }
@@ -406,6 +403,49 @@ impl TryFrom<&String> for Timestamp {
     }
 }
 
+/// Converts from [std::time::SystemTime] to [Timestamp].
+///
+/// This conversion may fail if the [std::time::SystemTime] value is out of
+/// range.
+///
+/// # Example
+/// ```
+/// # use std::time::SystemTime;
+/// # use google_cloud_wkt::{Timestamp, TimestampError};
+/// let ts = Timestamp::try_from(SystemTime::now())?;
+/// println!("now={ts:?}");
+/// # Ok::<(), anyhow::Error>(())
+/// ```
+impl TryFrom<std::time::SystemTime> for Timestamp {
+    type Error = TimestampError;
+    fn try_from(value: std::time::SystemTime) -> Result<Self, Self::Error> {
+        match value.duration_since(std::time::SystemTime::UNIX_EPOCH) {
+            Ok(d) => {
+                let s = d.as_secs();
+                if s > i64::MAX as u64 {
+                    return Err(TimestampError::OutOfRange);
+                }
+                Timestamp::new(s as i64, d.subsec_nanos() as i32)
+            }
+            Err(e) => {
+                // The error case essentially gives us a negative duration.
+                let d = e.duration();
+                let s = d.as_secs();
+                // We might add 1 to s later, but recall that `-i64::MIN == i64::MAX + 1`
+                if s > i64::MAX as u64 {
+                    return Err(TimestampError::OutOfRange);
+                }
+                let seconds = -(s as i64);
+                let nanos = d.subsec_nanos() as i32;
+                if nanos > 0 {
+                    return Timestamp::new(seconds - 1, Self::NS - nanos);
+                }
+                Timestamp::new(seconds, 0)
+            }
+        }
+    }
+}
+
 /// Converts from [chrono::DateTime] to [Timestamp].
 ///
 /// This conversion may fail if the [chrono::DateTime] value is out of range.
@@ -450,6 +490,40 @@ impl TryFrom<Timestamp> for chrono::DateTime<chrono::Utc> {
     }
 }
 
+/// Converts from [Timestamp] to [std::time::SystemTime].
+///
+/// This conversion may fail if the [std::time::SystemTime] value is out of
+/// range.
+///
+/// # Example
+/// ```
+/// # use std::time::SystemTime;
+/// # use google_cloud_wkt::{Timestamp, TimestampError};
+/// let ts = Timestamp::new(0, 0)?;
+/// let epoch = SystemTime::try_from(ts)?;
+/// assert_eq!(epoch, SystemTime::UNIX_EPOCH);
+/// # Ok::<(), anyhow::Error>(())
+/// ```
+impl TryFrom<Timestamp> for std::time::SystemTime {
+    type Error = TimestampError;
+    fn try_from(value: Timestamp) -> Result<std::time::SystemTime, Self::Error> {
+        let s = value.seconds();
+        let ts = if s >= 0 {
+            let d = std::time::Duration::from_secs(s as u64);
+            std::time::SystemTime::UNIX_EPOCH
+                .checked_add(d)
+                .ok_or_else(|| TimestampError::OutOfRange)?
+        } else {
+            let d = std::time::Duration::from_secs(-s as u64);
+            std::time::SystemTime::UNIX_EPOCH
+                .checked_sub(d)
+                .ok_or_else(|| TimestampError::OutOfRange)?
+        };
+        let d = std::time::Duration::from_nanos(value.nanos() as u64);
+        ts.checked_add(d).ok_or_else(|| TimestampError::OutOfRange)
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -726,4 +800,46 @@ mod tests {
         assert_eq!(got, want);
         Ok(())
     }
+
+    #[test]
+    fn convert_from_std_time() -> Result {
+        let now = std::time::SystemTime::now();
+        let want = now.duration_since(std::time::SystemTime::UNIX_EPOCH)?;
+
+        let wkt = Timestamp::try_from(now)?;
+        assert_eq!(wkt.seconds(), want.as_secs() as i64);
+        assert_eq!(wkt.nanos(), want.subsec_nanos() as i32);
+
+        let past = std::time::SystemTime::UNIX_EPOCH
+            .checked_sub(std::time::Duration::from_secs(123))
+            .unwrap()
+            .checked_sub(std::time::Duration::from_nanos(100))
+            .unwrap();
+        let wkt = Timestamp::try_from(past)?;
+        assert_eq!(wkt.seconds(), -124);
+        assert_eq!(wkt.nanos(), Timestamp::NS - 100);
+        Ok(())
+    }
+
+    #[test]
+    fn convert_to_std_time() -> Result {
+        let ts = Timestamp::clamp(123, 456789000);
+        let got = std::time::SystemTime::try_from(ts)?;
+        let want = std::time::SystemTime::UNIX_EPOCH
+            .checked_add(std::time::Duration::from_secs(123))
+            .unwrap()
+            .checked_add(std::time::Duration::from_nanos(456789000))
+            .unwrap();
+        assert_eq!(got, want);
+
+        let ts = Timestamp::clamp(-123, -456789000);
+        let got = std::time::SystemTime::try_from(ts)?;
+        let want = std::time::SystemTime::UNIX_EPOCH
+            .checked_sub(std::time::Duration::from_secs(123))
+            .unwrap()
+            .checked_sub(std::time::Duration::from_nanos(456789000))
+            .unwrap();
+        assert_eq!(got, want);
+        Ok(())
+    }
 }
