@@ -8,26 +8,29 @@ use std::{
 
 use digest::generic_array::GenericArray;
 use fs4::fs_std::FileExt;
-use parking_lot::Mutex;
+use rattler_conda_types::package::{IndexJson, PathsJson};
 use rattler_digest::Sha256Hash;
 
-use crate::package_cache::PackageCacheError;
+use crate::package_cache::PackageCacheLayerError;
 
-/// A lock on the cache entry. As long as this lock is held, no other process is
-/// allowed to modify the cache entry. This however, does not guarantee that the
-/// contents of the cache is not corrupted by external processes, but it does
-/// guarantee that when concurrent processes access the package cache they do
-/// not interfere with each other.
-pub struct CacheLock {
-    pub(super) _lock: CacheRwLock,
+/// A validated cache entry with its associated metadata.
+///
+/// This struct represents a cache entry that has been validated and is ready for use.
+/// It holds the cache entry's path, revision number, and optional SHA256 hash.
+///
+/// Note: Concurrent access is coordinated via the global cache lock mechanism
+/// (see [`CacheGlobalLock`]). Individual cache entries do not hold locks.
+pub struct CacheMetadata {
     pub(super) revision: u64,
     pub(super) sha256: Option<Sha256Hash>,
     pub(super) path: PathBuf,
+    pub(super) index_json: Option<IndexJson>,
+    pub(super) paths_json: Option<PathsJson>,
 }
 
-impl Debug for CacheLock {
+impl Debug for CacheMetadata {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("CacheLock")
+        f.debug_struct("CacheMetadata")
             .field("path", &self.path)
             .field("revision", &self.revision)
             .field("sha256", &self.sha256)
@@ -35,7 +38,7 @@ impl Debug for CacheLock {
     }
 }
 
-impl CacheLock {
+impl CacheMetadata {
     /// Returns the path to the cache entry on disk.
     pub fn path(&self) -> &Path {
         &self.path
@@ -46,69 +49,45 @@ impl CacheLock {
     pub fn revision(&self) -> u64 {
         self.revision
     }
+
+    /// Returns the cached `index.json` data if it was read during validation.
+    pub fn index_json(&self) -> Option<&IndexJson> {
+        self.index_json.as_ref()
+    }
+
+    /// Returns the cached `paths.json` data if it was read during validation.
+    pub fn paths_json(&self) -> Option<&PathsJson> {
+        self.paths_json.as_ref()
+    }
 }
 
-pub struct CacheRwLock {
-    file: Arc<Mutex<std::fs::File>>,
+/// A global lock for the entire package cache.
+///
+/// This can be used to reduce lock overhead when performing many package
+/// operations by acquiring a single global lock instead of individual per-package locks.
+pub struct CacheGlobalLock {
+    file: std::fs::File,
 }
 
-impl Drop for CacheRwLock {
+impl Debug for CacheGlobalLock {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("CacheGlobalLock").finish()
+    }
+}
+
+impl Drop for CacheGlobalLock {
     fn drop(&mut self) {
         // Ensure that the lock is released when the lock is dropped.
-        let _ = fs4::fs_std::FileExt::unlock(&*self.file.lock());
+        let _ = fs4::fs_std::FileExt::unlock(&self.file);
     }
 }
 
-impl CacheRwLock {
-    pub async fn acquire_read(path: &Path) -> Result<Self, PackageCacheError> {
-        let lock_file_path = path.to_path_buf();
-
-        let acquire_lock_fut = simple_spawn_blocking::tokio::run_blocking_task(move || {
-            let file = std::fs::OpenOptions::new()
-                .create(true)
-                .read(true)
-                .truncate(false)
-                .write(true)
-                .open(&lock_file_path)
-                .map_err(|e| {
-                    PackageCacheError::LockError(
-                        format!(
-                            "failed to open cache lock for reading: '{}'",
-                            lock_file_path.display()
-                        ),
-                        e,
-                    )
-                })?;
-
-            fs4::fs_std::FileExt::lock_shared(&file).map_err(move |e| {
-                PackageCacheError::LockError(
-                    format!(
-                        "failed to acquire read lock on cache lock file: '{}'",
-                        lock_file_path.display()
-                    ),
-                    e,
-                )
-            })?;
-
-            Ok(CacheRwLock {
-                file: Arc::new(Mutex::new(file)),
-            })
-        });
-
-        tokio::select!(
-            lock = acquire_lock_fut => lock,
-            _ = warn_timeout_future(format!(
-                "Blocking waiting for file lock on package cache for {}",
-                path.file_name()
-                    .expect("lock file must have a name")
-                    .to_string_lossy()
-            )) => unreachable!("warn_timeout_future should never finish")
-        )
-    }
-}
-
-impl CacheRwLock {
-    pub async fn acquire_write(path: &Path) -> Result<Self, PackageCacheError> {
+impl CacheGlobalLock {
+    /// Acquires a global write lock on the package cache.
+    ///
+    /// This lock should be used to coordinate access across multiple package
+    /// operations to reduce the overhead of acquiring individual locks.
+    pub async fn acquire(path: &Path) -> Result<Self, PackageCacheLayerError> {
         let lock_file_path = path.to_path_buf();
         let acquire_lock_fut = simple_spawn_blocking::tokio::run_blocking_task(move || {
             let file = std::fs::OpenOptions::new()
@@ -118,9 +97,9 @@ impl CacheRwLock {
                 .read(true)
                 .open(&lock_file_path)
                 .map_err(|e| {
-                    PackageCacheError::LockError(
+                    PackageCacheLayerError::LockError(
                         format!(
-                            "failed to open cache lock for writing: '{}",
+                            "failed to open global cache lock for writing: '{}'",
                             lock_file_path.display()
                         ),
                         e,
@@ -128,46 +107,83 @@ impl CacheRwLock {
                 })?;
 
             file.lock_exclusive().map_err(move |e| {
-                PackageCacheError::LockError(
+                PackageCacheLayerError::LockError(
                     format!(
-                        "failed to acquire write lock on cache lock file: '{}'",
+                        "failed to acquire write lock on global cache lock file: '{}'",
                         lock_file_path.display()
                     ),
                     e,
                 )
             })?;
 
-            Ok(CacheRwLock {
-                file: Arc::new(Mutex::new(file)),
-            })
+            Ok(CacheGlobalLock { file })
         });
 
         tokio::select!(
             lock = acquire_lock_fut => lock,
-            _ = warn_timeout_future(format!(
-                "Blocking waiting for file lock on package cache for {}",
-                path.file_name()
-                    .expect("lock file must have a name")
-                    .to_string_lossy()
-            )) => unreachable!("warn_timeout_future should never finish")
+            _ = warn_timeout_future(
+                "Blocking waiting for global file lock on package cache".to_string()
+            ) => unreachable!("warn_timeout_future should never finish")
         )
     }
 }
 
-impl CacheRwLock {
+/// A handle to a cache metadata file.
+///
+/// This struct manages access to a `.lock` file that stores metadata about a cache entry,
+/// including its revision number and optional SHA256 hash. It does not provide filesystem
+/// locking - concurrent access should be coordinated via [`CacheGlobalLock`].
+pub struct CacheMetadataFile {
+    file: Arc<std::fs::File>,
+}
+
+impl CacheMetadataFile {
+    /// Acquires a handle to the cache metadata file.
+    ///
+    /// Opens the file with both read and write permissions. Since concurrent access
+    /// is coordinated via [`CacheGlobalLock`], this single method is sufficient for
+    /// all metadata operations.
+    pub async fn acquire(path: &Path) -> Result<Self, PackageCacheLayerError> {
+        let lock_file_path = path.to_path_buf();
+
+        simple_spawn_blocking::tokio::run_blocking_task(move || {
+            let file = std::fs::OpenOptions::new()
+                .create(true)
+                .read(true)
+                .write(true)
+                .truncate(false)
+                .open(&lock_file_path)
+                .map_err(|e| {
+                    PackageCacheLayerError::LockError(
+                        format!(
+                            "failed to open cache metadata file: '{}'",
+                            lock_file_path.display()
+                        ),
+                        e,
+                    )
+                })?;
+
+            Ok(CacheMetadataFile {
+                file: Arc::new(file),
+            })
+        })
+        .await
+    }
+}
+
+impl CacheMetadataFile {
     pub async fn write_revision_and_sha(
         &mut self,
         revision: u64,
         sha256: Option<&Sha256Hash>,
-    ) -> Result<(), PackageCacheError> {
+    ) -> Result<(), PackageCacheLayerError> {
         let file = self.file.clone();
+
         let sha256 = sha256.cloned();
         simple_spawn_blocking::tokio::run_blocking_task(move || {
-            let mut file = file.lock();
-
             // Ensure we write from the start of the file
-            file.rewind().map_err(|e| {
-                PackageCacheError::LockError(
+            (&*file).rewind().map_err(|e| {
+                PackageCacheLayerError::LockError(
                     "failed to rewind cache lock for reading revision".to_string(),
                     e,
                 )
@@ -175,8 +191,8 @@ impl CacheRwLock {
 
             // Write the bytes of the revision
             let revision_bytes = revision.to_be_bytes();
-            file.write_all(&revision_bytes).map_err(|e| {
-                PackageCacheError::LockError(
+            (&*file).write_all(&revision_bytes).map_err(|e| {
+                PackageCacheLayerError::LockError(
                     "failed to write revision from cache lock".to_string(),
                     e,
                 )
@@ -186,8 +202,8 @@ impl CacheRwLock {
             let sha_bytes = if let Some(sha) = sha256 {
                 let len = sha.len();
                 let sha = &sha[..];
-                file.write_all(sha).map_err(|e| {
-                    PackageCacheError::LockError(
+                (&*file).write_all(sha).map_err(|e| {
+                    PackageCacheLayerError::LockError(
                         "failed to write sha256 from cache lock".to_string(),
                         e,
                     )
@@ -198,8 +214,8 @@ impl CacheRwLock {
             };
 
             // Ensure all bytes are written to disk
-            file.flush().map_err(|e| {
-                PackageCacheError::LockError(
+            (&*file).flush().map_err(|e| {
+                PackageCacheLayerError::LockError(
                     "failed to flush cache lock after writing revision".to_string(),
                     e,
                 )
@@ -208,7 +224,7 @@ impl CacheRwLock {
             // Update the length of the file
             let file_length = revision_bytes.len() + sha_bytes;
             file.set_len(file_length as u64).map_err(|e| {
-                PackageCacheError::LockError(
+                PackageCacheLayerError::LockError(
                     "failed to truncate cache lock after writing revision".to_string(),
                     e,
                 )
@@ -218,26 +234,23 @@ impl CacheRwLock {
         })
         .await
     }
-}
 
-impl CacheRwLock {
-    /// Reads the revision from the cache lock file.
-    pub fn read_revision(&mut self) -> Result<u64, PackageCacheError> {
-        let mut file = self.file.lock();
-        file.rewind().map_err(|e| {
-            PackageCacheError::LockError(
+    /// Reads the revision from the cache metadata file.
+    pub fn read_revision(&mut self) -> Result<u64, PackageCacheLayerError> {
+        (&*self.file).rewind().map_err(|e| {
+            PackageCacheLayerError::LockError(
                 "failed to rewind cache lock for reading revision".to_string(),
                 e,
             )
         })?;
         let mut buf = [0; 8];
-        match file.read_exact(&mut buf) {
+        match (&*self.file).read_exact(&mut buf) {
             Ok(_) => {}
             Err(e) if e.kind() == std::io::ErrorKind::UnexpectedEof => {
                 return Ok(0);
             }
             Err(e) => {
-                return Err(PackageCacheError::LockError(
+                return Err(PackageCacheLayerError::LockError(
                     "failed to read revision from cache lock".to_string(),
                     e,
                 ));
@@ -246,28 +259,32 @@ impl CacheRwLock {
         Ok(u64::from_be_bytes(buf))
     }
 
-    /// Reads the sha256 hash from the cache lock file.
-    pub fn read_sha256(&mut self) -> Result<Option<Sha256Hash>, PackageCacheError> {
+    /// Reads the sha256 hash from the cache metadata file.
+    pub fn read_sha256(&mut self) -> Result<Option<Sha256Hash>, PackageCacheLayerError> {
         const SHA256_LEN: usize = 32;
         const REVISION_LEN: u64 = 8;
-        let mut file = self.file.lock();
-        file.rewind().map_err(|e| {
-            PackageCacheError::LockError(
+        (&*self.file).rewind().map_err(|e| {
+            PackageCacheLayerError::LockError(
                 "failed to rewind cache lock for reading sha256".to_string(),
                 e,
             )
         })?;
         let mut buf = [0; SHA256_LEN];
-        let _ = file.seek(SeekFrom::Start(REVISION_LEN)).map_err(|e| {
-            PackageCacheError::LockError("failed to seek to sha256 in cache lock".to_string(), e)
-        })?;
-        match file.read_exact(&mut buf) {
+        let _ = (&*self.file)
+            .seek(SeekFrom::Start(REVISION_LEN))
+            .map_err(|e| {
+                PackageCacheLayerError::LockError(
+                    "failed to seek to sha256 in cache lock".to_string(),
+                    e,
+                )
+            })?;
+        match (&*self.file).read_exact(&mut buf) {
             Ok(_) => {}
             Err(e) if e.kind() == std::io::ErrorKind::UnexpectedEof => {
                 return Ok(None);
             }
             Err(e) => {
-                return Err(PackageCacheError::LockError(
+                return Err(PackageCacheLayerError::LockError(
                     "failed to read sha256 from cache lock".to_string(),
                     e,
                 ));
@@ -288,24 +305,27 @@ async fn warn_timeout_future(message: String) {
 mod tests {
     use rattler_digest::{parse_digest_from_hex, Sha256};
 
-    use super::CacheRwLock;
+    use super::CacheMetadataFile;
 
     #[tokio::test]
-    async fn cache_lock_serialize_deserialize() {
-        // Temporarily create a lock file and write a revision and sha to it
+    async fn cache_metadata_serialize_deserialize() {
+        // Temporarily create a metadata file and write a revision and sha to it
         let temp_dir = tempfile::tempdir().unwrap();
-        let lock_file = temp_dir.path().join("foo.lock");
-        // Acquire a write lock on the file
-        let mut lock = CacheRwLock::acquire_write(&lock_file).await.unwrap();
+        let metadata_file = temp_dir.path().join("foo.lock");
+        // Acquire a handle on the file
+        let mut metadata = CacheMetadataFile::acquire(&metadata_file).await.unwrap();
         // Write a revision and sha to the lock file
         let sha = parse_digest_from_hex::<Sha256>(
             "4dd9893f1eee45e1579d1a4f5533ef67a84b5e4b7515de7ed0db1dd47adc6bc8",
         );
-        lock.write_revision_and_sha(1, sha.as_ref()).await.unwrap();
-        // Read back the revision and sha from the lock file
-        let revision = lock.read_revision().unwrap();
+        metadata
+            .write_revision_and_sha(1, sha.as_ref())
+            .await
+            .unwrap();
+        // Read back the revision and sha from the metadata file
+        let revision = metadata.read_revision().unwrap();
         assert_eq!(revision, 1);
-        let read_sha = lock.read_sha256().unwrap();
+        let read_sha = metadata.read_sha256().unwrap();
         assert_eq!(sha, read_sha);
     }
 }
