@@ -4,8 +4,7 @@ use nom::{
     character::complete::char,
     combinator::opt,
     error::{ErrorKind, ParseError},
-    sequence::tuple,
-    IResult,
+    IResult, Parser,
 };
 use thiserror::Error;
 
@@ -100,7 +99,7 @@ fn regex_constraint_parser(
 ) -> impl FnMut(&str) -> IResult<&str, Constraint, ParseConstraintError> {
     move |input: &str| {
         let (_rest, (preceder, _, terminator)) =
-            tuple((opt(char('^')), take_while(|c| c != '$'), opt(char('$'))))(input)?;
+            (opt(char('^')), take_while(|c| c != '$'), opt(char('$'))).parse(input)?;
         match (preceder, terminator) {
             (None, None) => Err(nom::Err::Error(ParseConstraintError::UnterminatedRegex)),
             (_, None) | (None, _) => {
@@ -118,7 +117,7 @@ fn any_constraint_parser(
     strictness: ParseStrictness,
 ) -> impl FnMut(&str) -> IResult<&str, Constraint, ParseConstraintError> {
     move |input: &str| {
-        let (remaining, (_, trailing)) = tuple((tag("*"), opt(tag(".*"))))(input)?;
+        let (remaining, (_, trailing)) = (tag("*"), opt(tag(".*"))).parse(input)?;
 
         // `*.*` is not allowed in strict mode
         if trailing.is_some() && strictness == ParseStrictness::Strict {
@@ -333,7 +332,8 @@ pub fn constraint_parser(
             regex_constraint_parser(strictness),
             any_constraint_parser(strictness),
             logical_constraint_parser(strictness),
-        ))(input)
+        ))
+        .parse(input)
     }
 }
 
