@@ -2,7 +2,9 @@
 use crate::encoder_options::EncoderOptions;
 use crate::{NtTime, bitset::BitSet, block::*};
 
-pub(crate) const SIGNATURE_HEADER_SIZE: u64 = 32;
+/// Size of the 7z signature header in bytes (32 bytes).
+/// This is needed for calculating absolute byte offsets within the archive.
+pub const SIGNATURE_HEADER_SIZE: u64 = 32;
 pub(crate) const SEVEN_Z_SIGNATURE: &[u8] = &[b'7', b'z', 0xBC, 0xAF, 0x27, 0x1C];
 
 pub(crate) const K_END: u8 = 0x00;
@@ -57,6 +59,20 @@ pub struct Archive {
     pub is_solid: bool,
 }
 
+impl Archive {
+    /// Returns the offset from beginning of file + SIGNATURE_HEADER_SIZE to packed streams.
+    /// Used for calculating byte offsets when streaming uncompressed (COPY) content.
+    pub fn pack_pos(&self) -> u64 {
+        self.pack_pos
+    }
+
+    /// Returns the sizes of each packed stream in bytes.
+    /// Used for calculating byte ranges when streaming.
+    pub fn pack_sizes(&self) -> &[u64] {
+        &self.pack_sizes
+    }
+}
+
 #[derive(Debug, Default, Clone)]
 pub(crate) struct SubStreamsInfo {
     pub(crate) unpack_sizes: Vec<u64>,
@@ -454,6 +470,20 @@ pub struct StreamMap {
     pub file_block_index: Vec<Option<usize>>,
 }
 
+impl StreamMap {
+    /// Returns the index of the first pack stream for each block.
+    /// Used for mapping blocks to their packed data streams.
+    pub fn block_first_pack_stream_index(&self) -> &[usize] {
+        &self.block_first_pack_stream_index
+    }
+
+    /// Returns byte offsets of each pack stream within the packed data region.
+    /// Combined with pack_pos and SIGNATURE_HEADER_SIZE to get absolute offsets.
+    pub fn pack_stream_offsets(&self) -> &[u64] {
+        &self.pack_stream_offsets
+    }
+}
+
 #[derive(Debug, Clone, Copy)]
 pub(crate) struct StartHeader {
     pub(crate) next_header_offset: u64,
