@@ -11,7 +11,7 @@
 )]
 #![allow(
     clippy::module_name_repetitions,
-    unused_unsafe // for nightly
+    unused_unsafe, // for nightly
 )]
 #![doc = include_str!(concat!(env!("CARGO_MANIFEST_DIR"), "/README.md"))]
 
@@ -123,7 +123,7 @@ impl Buffers {
 ///
 /// Will return `Err` if `s` is invalid JSON.
 #[cfg_attr(not(feature = "no-inline"), inline)]
-pub fn to_tape(s: &mut [u8]) -> Result<Tape> {
+pub fn to_tape(s: &mut [u8]) -> Result<Tape<'_>> {
     Deserializer::from_slice(s).map(Deserializer::into_tape)
 }
 
@@ -916,7 +916,7 @@ impl<'de> Deserializer<'de> {
         // expensive carryless multiply in the previous step with this work
         let mut structurals: u64 = 0;
 
-        let lenminus64: usize = if len < 64 { 0 } else { len - 64 };
+        let lenminus64: usize = len.saturating_sub(64);
         let mut idx: usize = 0;
         let mut error_mask: u64 = 0; // for unescaped characters within strings (ASCII code points < 0x20)
 
